==> zio-aws-kinesisanalytics_2.13-5.17.121.3-sources.jar: zio/aws/kinesisanalytics/model/InputParallelismUpdate.scala <==
package zio.aws.kinesisanalytics.model
import java.lang.Integer
import zio.aws.kinesisanalytics.model.primitives.InputParallelismCount
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InputParallelismUpdate(
    countUpdate: Option[InputParallelismCount] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate = {
    import InputParallelismUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
      .builder()
      .optionallyWith(
        countUpdate.map(value => InputParallelismCount.unwrap(value): Integer)
      )(_.countUpdate)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.InputParallelismUpdate.ReadOnly =
    zio.aws.kinesisanalytics.model.InputParallelismUpdate.wrap(buildAwsValue())
}
object InputParallelismUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalytics.model.InputParallelismUpdate =
      zio.aws.kinesisanalytics.model
        .InputParallelismUpdate(countUpdate.map(value => value))
    def countUpdate: Option[InputParallelismCount]
    def getCountUpdate: ZIO[Any, AwsError, InputParallelismCount] =
      AwsError.unwrapOptionField("countUpdate", countUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
  ) extends zio.aws.kinesisanalytics.model.InputParallelismUpdate.ReadOnly {
    override val countUpdate: Option[InputParallelismCount] = scala
      .Option(impl.countUpdate())
      .map(value =>
        zio.aws.kinesisanalytics.model.primitives.InputParallelismCount(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
  ): zio.aws.kinesisanalytics.model.InputParallelismUpdate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalytics_2.13-7.21.15.10-sources.jar: zio/aws/kinesisanalytics/model/InputParallelismUpdate.scala <==
package zio.aws.kinesisanalytics.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.kinesisanalytics.model.primitives.InputParallelismCount
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class InputParallelismUpdate(
    countUpdate: Optional[InputParallelismCount] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate = {
    import InputParallelismUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
      .builder()
      .optionallyWith(
        countUpdate.map(value => InputParallelismCount.unwrap(value): Integer)
      )(_.countUpdate)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.InputParallelismUpdate.ReadOnly =
    zio.aws.kinesisanalytics.model.InputParallelismUpdate.wrap(buildAwsValue())
}
object InputParallelismUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalytics.model.InputParallelismUpdate =
      zio.aws.kinesisanalytics.model
        .InputParallelismUpdate(countUpdate.map(value => value))
    def countUpdate: Optional[InputParallelismCount]
    def getCountUpdate: ZIO[Any, AwsError, InputParallelismCount] =
      AwsError.unwrapOptionField("countUpdate", countUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
  ) extends zio.aws.kinesisanalytics.model.InputParallelismUpdate.ReadOnly {
    override val countUpdate: Optional[InputParallelismCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.countUpdate())
        .map(value =>
          zio.aws.kinesisanalytics.model.primitives.InputParallelismCount(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputParallelismUpdate
  ): zio.aws.kinesisanalytics.model.InputParallelismUpdate.ReadOnly =
    new Wrapper(impl)
}
